@@ -1,7 +1,7 @@
 from enum import Enum
 
 
-class GeneratorTypes(Enum):
+class OutputTypes(Enum):
     CONDA = "conda"
     REQUIREMENTS = "requirements"
     NONE = "none"
@@ -10,16 +10,14 @@ class GeneratorTypes(Enum):
         return self.value
 
 
-conda_and_requirements_key = f"{GeneratorTypes.CONDA}_and_{GeneratorTypes.REQUIREMENTS}"
-
 cli_name = "rapids-dependency-file-generator"
 
 default_channels = [
     "rapidsai",
-    "nvidia",
     "rapidsai-nightly",
     "dask/label/dev",
     "conda-forge",
+    "nvidia",
 ]
 
 default_conda_dir = "conda/environments"
